

To intsall this package

For this we run
```bash
python3 -m venv myenv
source myenv/bin/activate
pip install -i https://test.pypi.org/simple/voronoi_cell
python3 -m pip install voronoi_cell
```

To install and test the example package
```bash
```
